==> naim-0.9.3.tgz: naim-0.9.3/include/naim.h <==
/*  _ __   __ _ ___ __  __
** | '_ \ / _` |_ _|  \/  | nAIM PRERELEASE
** | | | | (_| || || |\/| | Copyright 1998 Daniel Reed <n@ml.org>
** |_| |_|\__,_|___|_|  |_| ncurses-based, FAIM-based AIM client
**
** Based on ProtoFAIM v0.xx.xxplxx (faimtest.c) by Adam Fritzler
** FAIM Copyright 1998 Adam Fritzler <afritz@iname.com>
** FAIM uses code Copyright 1998 Brock Wilcox <awwaiid@iname.com>
*/
#ifndef naim_h
#define naim_h	1

#include <config.h>
#include <aim.h>

#include <stdarg.h>

#ifdef HAVE_CTYPE_H
# include <ctype.h>
#endif
#ifdef HAVE_ERRNO_H
# include <errno.h>
#endif
#ifdef HAVE_SYS_ERRNO_H
# include <sys/errno.h>
#endif
#ifdef HAVE_STDLIB_H
# include <stdlib.h>
#endif

#ifdef HAVE_NCURSES_H
# include <ncurses.h>
#else
# ifdef HAVE_CURSES_H
#  include <curses.h>
# else
#  error Unable to locate ncurses.h; please see README.ncurses
# endif
#endif

#ifndef NO_HISTORY
# ifdef HAVE_READLINE_HISTORY_H
#  include <readline/history.h>
# else
#  ifdef HAVE_HISTORY_H
#   include <history.h>
#  else
#   error Unable to locate history.h; please see README.history
#  endif
# endif
#endif

#ifdef HAVE_ASSERT_H
# include <assert.h>
#else
# define assert(x)
#endif

#ifdef HAVE_TIME_H
# include <time.h>
# ifdef HAVE_SYS_TIME_H
#  ifdef TIME_WITH_SYS_TIME
#   include <sys/time.h>
#  endif
# endif
#else
# ifdef HAVE_SYS_TIME_H
#  include <sys/time.h>
# endif
#endif

// no, this isn't where you configure the colours; this just sets up the
// pair numerics, the pairs are associated with actual colours in win.c
#define IMWIN_BGCOLOR	20
#define IMWIN_TEXT_U	21
#define IMWIN_TEXT_R	22
#define IMWIN_STATUS	23

#define INPUT_BGCOLOR	30
#define INPUT_TEXT	31
#define INPUT_TEXT_ALT	32

#define BUDDY_BGCOLOR	40
#define BUDDY_TEXT	41
#define BUDDY_WAITING	42
#define BUDDY_OFFLINE	43
#define BUDDY_NONBUDDY	44

#define STAT_BGCOLOR	50
#define STAT_TEXT	51

#define BACKDROP	60

typedef struct {
	char	screenname[11], msg[1024], autoreply;
	unsigned long	membersince, onsince;
	unsigned short	class, idletime;
} IMpack_t;

typedef struct buddywin_ts {
	char	winname[13];
	char	waiting,	// text waiting to be read (overrides
				// offline and isbuddy in bupdate())
		offline,	// window currently points to offline person
		notbuddy,	// window is for a non-buddy
		keepafterso;	// keep window open after buddy signs off?
	WINDOW	*win;
	struct buddywin_ts	*next;
	time_t	informed;
} buddywin_t;

typedef struct buddylist_ts {
	char	screenname[11],
		group[21],
		notes[21];
	struct buddylist_ts	*next;
} buddylist_t;

typedef struct ignorelist_ts {
	char	screenname[11],
		notes[128];
	struct ignorelist_ts	*next;
	time_t	informed;
} ignorelist_t;

typedef struct {
	char	screenname[11],
		password[16],
		awaymsg[256],
		logfile[128],
		*profile,
		beeponim, beeponsignon, autoaway, nolog, tprint;
	buddylist_t	*buddies;
	ignorelist_t	*idiots;
	int	cols;
	struct {
		char	fore, back;
	} colors[64];
	struct {
		int	startx, starty,
			widthx, widthy;
	} wstatus, winput, wbuddy;
} faimconf_t;

/* aimio.c */
int	naim_login_phase3d_f(struct command_rx_struct *);
int	naim_buddy_coming(struct command_rx_struct *);
int	naim_buddy_going(struct command_rx_struct *);
int	naim_im_breakdown(struct command_rx_struct *);
int	naim_im_handle(IMpack_t *);
int	naim_userinfo_handler(struct command_rx_struct *);

/* atomizer.c */
char	*firstatom(char *, char *);
char	*firstwhite(char *);
char	*atom(char *);

/* buddy.c */
void	bsetup(void);
void	bnewwin(char *);
void	bupdate(void);
void	bcoming(char *);
void	bgoing(char *);
void	bremove(buddywin_t *);
buddywin_t	*bgetwin(char *);

/* conio.c */
void	gotkey(int);
void	updateidletime(void);

/* hamster.c */
void	logim(char *, char *, char *);
void	naim_send_im(char *, char *);
void	naim_send_im_away(char *, char *);
void	setaway(void);
void	unsetaway(void);
void	sendaway(char *);

/* hwprintf.c */
int	hwprintf(WINDOW *, int, const char *, ...);

/* rc.c */
void	killconf(faimconf_t *);
buddylist_t	*rgetlist(faimconf_t *, char *);
char	*rmakebuddyar(faimconf_t *);
int	naim_read_config(char *);

/* rodents.c */
int	aimcmp(char *, char *);

/* win.c */
void	wsetp(void);
void	wsetup(void);
int	wcols(faimconf_t *);
void	winitwin(WINDOW *, int);
int	wprintf(WINDOW *, int, int, const char *, ...);
void	wshutitdown(void);

#endif /* naim_h */

==> naim-0.9.4.tgz: naim-0.9.4/include/naim.h <==
/*  _ __   __ _ ___ __  __
** | '_ \ / _` |_ _|  \/  | nAIM PRERELEASE
** | | | | (_| || || |\/| | Copyright 1998 Daniel Reed <n@ml.org>
** |_| |_|\__,_|___|_|  |_| ncurses-based, FAIM-based AIM client
**
** Based on ProtoFAIM v0.xx.xxplxx (faimtest.c) by Adam Fritzler
** FAIM Copyright 1998 Adam Fritzler <afritz@iname.com>
** FAIM uses code Copyright 1998 Brock Wilcox <awwaiid@iname.com>
*/
#ifndef naim_h
#define naim_h	1

#include <config.h>
#include <../secs/secs.h>
#include <aim.h>

#include <stdarg.h>

#ifdef HAVE_CTYPE_H
# include <ctype.h>
#endif
#ifdef HAVE_ERRNO_H
# include <errno.h>
#endif
#ifdef HAVE_SYS_ERRNO_H
# include <sys/errno.h>
#endif
#ifdef HAVE_STDLIB_H
# include <stdlib.h>
#endif

#ifdef HAVE_NCURSES_H
# include <ncurses.h>
#else
# ifdef HAVE_CURSES_H
#  include <curses.h>
# else
#  error Unable to locate ncurses.h; please see README.ncurses
# endif
#endif

#ifndef NO_HISTORY
# ifdef HAVE_READLINE_HISTORY_H
#  include <readline/history.h>
# else
#  ifdef HAVE_HISTORY_H
#   include <history.h>
#  else
#   error Unable to locate history.h; please see README.history
#  endif
# endif
#endif

#ifdef HAVE_ASSERT_H
# include <assert.h>
#else
# define assert(x)
#endif

#ifdef HAVE_TIME_H
# include <time.h>
# ifdef HAVE_SYS_TIME_H
#  ifdef TIME_WITH_SYS_TIME
#   include <sys/time.h>
#  endif
# endif
#else
# ifdef HAVE_SYS_TIME_H
#  include <sys/time.h>
# endif
#endif

// no, this isn't where you configure the colours; this just sets up the
// pair numerics, the pairs are associated with actual colours in win.c
#define HELP_HELP	10
#define HELP_TEXT	11

#define IMWIN_BGCOLOR	20
#define IMWIN_TEXT_U	21
#define IMWIN_TEXT_R	22
#define IMWIN_STATUS	23

#define INPUT_BGCOLOR	30
#define INPUT_TEXT	31
#define INPUT_TEXT_ALT	32

#define BUDDY_BGCOLOR	40
#define BUDDY_TEXT	41
#define BUDDY_WAITING	42
#define BUDDY_OFFLINE	43
#define BUDDY_NONBUDDY	44

#define STAT_BGCOLOR	50
#define STAT_TEXT	51

#define BACKDROP	60


#define CONIO_MAXPARMS	10

typedef struct {
	char	screenname[11], msg[1024], autoreply;
	unsigned long	membersince, onsince;
	unsigned short	class, idletime;
} IMpack_t;

typedef struct buddywin_ts {
	char	winname[11];
	char	waiting,	// text waiting to be read (overrides
				// offline and isbuddy in bupdate())
		offline,	// window currently points to offline person
		notbuddy,	// window is for a non-buddy
		keepafterso;	// keep window open after buddy signs off?
	WINDOW	*win;
	struct buddywin_ts	*next;
	time_t	informed;
} buddywin_t;

typedef struct buddylist_ts {
	char	screenname[11],
		group[21],
		notes[41];
	struct buddylist_ts	*next;
} buddylist_t;

typedef struct ignorelist_ts {
	char	screenname[11],
		notes[128];
	struct ignorelist_ts	*next;
	time_t	informed;
} ignorelist_t;

typedef struct {
	char	screenname[11],
		password[16],
		logfile[128],
		*profile,
		nolog;
	buddylist_t	*buddies;
	ignorelist_t	*idiots;
	int	cols;
	struct {
		char	fore, back;
	} colors[64];
	struct {
		int	startx, starty,
			widthx, widthy;
	} wstatus, winput, wbuddy;
} faimconf_t;

/* aimio.c */
int	naim_login_phase3d_f(struct command_rx_struct *);
int	naim_buddy_coming(struct command_rx_struct *);
int	naim_buddy_going(struct command_rx_struct *);
int	naim_im_breakdown(struct command_rx_struct *);
int	naim_im_handle(IMpack_t *);
int	naim_userinfo_handler(struct command_rx_struct *);

/* buddy.c */
void	bsetup(void);
void	bnewwin(char *);
void	bupdate(void);
void	bcoming(char *);
void	bgoing(char *);
void	bremove(buddywin_t *);
buddywin_t	*bgetwin(char *);

/* conio.c */
int	conio_handlecmd(char *);
void	gotkey(int);

/* events.c */
void	updateidletime(void);
void	event_handle(time_t);

/* hamster.c */
void	logim(char *, char *, char *);
void	naim_send_im(char *, char *);
void	naim_send_im_away(char *, char *);
void	setaway(void);
void	unsetaway(void);
void	sendaway(char *);

/* helpcmd.c */
void	help_printhelp(char *);

/* hwprintf.c */
int	hwprintf(WINDOW *, int, const char *, ...);

/* rc.c */
void	killconf(faimconf_t *);
buddylist_t	*rgetlist(faimconf_t *, char *);
char	*rmakebuddyar(faimconf_t *);
int	naim_read_config(char *);

/* rodents.c */
int	aimcmp(char *, char *);

/* script.c */
int	script_doalias(char *, char *);

/* set.c */
void	set_setvar(char *);

/* win.c */
void	wsetp(void);
void	wsetup(void);
int	wcols(faimconf_t *);
void	winitwin(WINDOW *, int);
int	wprintf(WINDOW *, int, int, const char *, ...);
void	wshutitdown(void);

#endif /* naim_h */
